@@ -6,6 +6,7 @@ import argparse
 
 from typing import List
 
+from predectorutils import __version__, __email__
 from predectorutils.subcommands.r2js import cli as r2js_cli
 from predectorutils.subcommands.r2js import runner as r2js_runner
 
@@ -27,14 +28,24 @@ from predectorutils.subcommands.rank import runner as rank_runner
 from predectorutils.subcommands.decode import cli as decode_cli
 from predectorutils.subcommands.decode import runner as decode_runner
 
+from predectorutils.subcommands.regex import cli as regex_cli
+from predectorutils.subcommands.regex import runner as regex_runner
+
+from predectorutils.subcommands.precomputed import cli as precomp_cli
+from predectorutils.subcommands.precomputed import runner as precomp_runner
+
+from predectorutils.subcommands.load_db import cli as load_db_cli
+from predectorutils.subcommands.load_db import runner as load_db_runner
+
+from predectorutils.subcommands.dump_db import cli as dump_db_cli
+from predectorutils.subcommands.dump_db import runner as dump_db_runner
+
 from predectorutils.parsers import ParseError
 from predectorutils.exceptions import (
     EXIT_VALID, EXIT_KEYBOARD, EXIT_UNKNOWN, EXIT_CLI, EXIT_INPUT_FORMAT,
     EXIT_INPUT_NOT_FOUND, EXIT_SYSERR, EXIT_CANT_OUTPUT
 )
 
-__email__ = "darcy.ab.jones@gmail.com"
-
 
 class MyArgumentParser(argparse.ArgumentParser):
 
@@ -78,6 +89,13 @@ def cli(prog: str, args: List[str]) -> argparse.Namespace:
         )
     )
 
+    parser.add_argument(
+        '--version',
+        action='version',
+        version='{}'.format(__version__),
+        help="Print the version of %(prog)s and exit"
+    )
+
     subparsers = parser.add_subparsers(dest="subparser_name")
     r2js_subparser = subparsers.add_parser(
         "r2js",
@@ -143,6 +161,42 @@ def cli(prog: str, args: List[str]) -> argparse.Namespace:
 
     decode_cli(decode_subparser)
 
+    regex_subparser = subparsers.add_parser(
+        "regex",
+        help=(
+            "Search for a regular expression in sequences."
+        )
+    )
+
+    regex_cli(regex_subparser)
+
+    precomp_subparser = subparsers.add_parser(
+        "precomputed",
+        help=(
+            "Fetch precomputed results and output remaining sequences."
+        )
+    )
+
+    precomp_cli(precomp_subparser)
+
+    load_db_subparser = subparsers.add_parser(
+        "load_db",
+        help=(
+            "Load ldjson results into an SQlite database."
+        )
+    )
+
+    load_db_cli(load_db_subparser)
+
+    dump_db_subparser = subparsers.add_parser(
+        "dump_db",
+        help=(
+            "Dump an SQLite database into ldjson results."
+        )
+    )
+
+    dump_db_cli(dump_db_subparser)
+
     parsed = parser.parse_args(args)
 
     if parsed.subparser_name is None:
@@ -174,6 +228,14 @@ def main():  # noqa
             rank_runner(args)
         elif args.subparser_name == "decode":
             decode_runner(args)
+        elif args.subparser_name == "regex":
+            regex_runner(args)
+        elif args.subparser_name == "precomputed":
+            precomp_runner(args)
+        elif args.subparser_name == "load_db":
+            load_db_runner(args)
+        elif args.subparser_name == "dump_db":
+            dump_db_runner(args)
 
     except ParseError as e:
         if e.line is not None:
@@ -191,6 +253,7 @@ def main():  # noqa
             "We can't control these, and they're usually related to your OS.\n"
             "Try running again.\n"
         )
+        raise e
         print(msg, file=sys.stderr)
         print(e.strerror, file=sys.stderr)
         sys.exit(EXIT_SYSERR)
@@ -215,7 +278,7 @@ def main():  # noqa
             "authors.\nWe will be extremely grateful!\n\n"
             "You can email us at {}.\n"
             "Alternatively, you can file the issue directly on the repo "
-            "<https://bitbucket.org/ccdm-curtin/catastrophy/issues>\n\n"
+            "<https://github.com/ccdmb/predector-utils>\n\n"
             "Please attach a copy of the following message:"
         ).format(__email__)
         print(e, file=sys.stderr)
